# jai - A LEGO-style PyTorch-based Deep Learning Library

## Dev. Plan
1. Refactor the augmentation pipeline
2. Clean up the code in arch
3. Implement the check failure case method. Use open cv + keyboard control
